"""
Payout Query Exception gets raised when request for payout retrieval gets failed .
"""

from .payout_exception import PayoutException


class PayoutQueryException(PayoutException):
    """
    PayoutQueryException
    """

    __bitpay_message = "Failed to retrieve payout"
    __bitpay_code = "BITPAY-PAYOUT-GET"
    __api_code = ""

    def __init__(self, message: str, code: int = 123, api_code: str = "000000"):
        """
        Construct the PayoutQueryException.

        :param message: The Exception message to throw.
        :param code: [optional] The Exception code to throw.
        :param api_code: [optional] The API Exception code to throw.
        """
        message = self.__bitpay_code + ": " + self.__bitpay_message + ":" + message
        self.__api_code = api_code
        super().__init__(message, code)
